@@ -13,6 +13,22 @@
 
    See the examples for more details.
 
+   ## How to install?
+
+   Include `plotters-iced` in your `Cargo.toml` dependencies:
+
+   ```toml
+   [dependencies]
+   plotters-iced = "0.1"
+   iced = { version = "0.3", features = ["canvas", "tokio"] }
+   plotters="0.3"
+   ```
+
+   ## Showcase
+
+   ![CPU Monitor Example](https://cdn.jsdelivr.net/gh/Joylei/plotters-iced@0.1.0/images/plotter_iced_demo.png)
+
+
    ## Example
    ```rust,ignore
    struct MyChart;
@@ -31,7 +47,7 @@
       }
    }
    ```
-
+   See the [examples](https://github.com/Joylei/plotters-iced/tree/master/examples) for more details.
 */
 
 extern crate iced_graphics;
@@ -45,7 +61,9 @@ mod error;
 mod triangulate;
 mod utils;
 
-pub use chart::Chart;
-pub use chart::ChartWidget;
-pub use plotters::chart::ChartBuilder;
+#[doc(inline)]
+pub use chart::{Chart, ChartWidget};
+#[doc(no_inline)]
+pub use plotters::{chart::ChartBuilder, drawing::DrawingArea};
+#[doc(no_inline)]
 pub use plotters_backend::DrawingBackend;
